#include <Servo.h>

#define BUTTON_PIN_1 12   // Pin connecté au premier bouton poussoir
#define BUTTON_PIN_2 10   // Pin connecté au deuxième bouton poussoir
#define BUTTON_PIN_3 9    // Pin connecté au troisième bouton poussoir
#define SERVO_PIN_1 8     // Pin connecté au premier servo
#define SERVO_PIN_2 11    // Pin connecté au deuxième servo

Servo myServo1;
Servo myServo2;

int angle1 = 35;  // Angle initial du premier servo
int angle2 = 65;  // Angle initial du deuxième servo
bool taskInProgress1 = false; // Indique si la tâche du premier servo est en cours
bool taskInProgress2 = false; // Indique si la tâche du deuxième servo est en cours
bool taskInProgress3 = false; // Indique si la tâche du troisième bouton est en cours

int in1 = 2;
int in2 = 4;
int enA = 3;

int in3 = 5;
int in4 = 7;
int enB = 6;

void setup() {
  pinMode(BUTTON_PIN_1, INPUT_PULLUP);  // Configure le pin du premier bouton comme entrée avec résistance pull-up
  pinMode(BUTTON_PIN_2, INPUT_PULLUP);  // Configure le pin du deuxième bouton comme entrée avec résistance pull-up
  pinMode(BUTTON_PIN_3, INPUT_PULLUP);  // Configure le pin du troisième bouton comme entrée avec résistance pull-up
  myServo1.attach(SERVO_PIN_1);          // Attache le premier servo au pin désigné
  myServo1.write(angle1);               // Place le premier servo à l'angle initial
  myServo2.attach(SERVO_PIN_2);          // Attache le deuxième servo au pin désigné
  myServo2.write(angle2);               // Place le deuxième servo à l'angle initial
  pinMode(enA, OUTPUT);
  pinMode(in1, OUTPUT);
  pinMode(in2, OUTPUT);
  pinMode(enB, OUTPUT);
  pinMode(in3, OUTPUT);
  pinMode(in4, OUTPUT);
}

void loop() {
  // Vérifie si le premier bouton est appuyé et si aucune tâche du premier servo n'est en cours
  if (digitalRead(BUTTON_PIN_1) == LOW && !taskInProgress1) {
    taskInProgress1 = true; // Marquer la tâche du premier servo comme en cours
    angle1 = 0; // Déplacer le premier servo à 0 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à ce nouvel angle

    // Tourner les moteurs vers l'avant
    digitalWrite(in1, HIGH);
    digitalWrite(in2, LOW);
    digitalWrite(in3, HIGH);
    digitalWrite(in4, LOW);
    analogWrite(enA, 100); // Utiliser analogWrite pour la vitesse
    analogWrite(enB, 100); // Utiliser analogWrite pour la vitesse
    delay(1000);

    // Arrêter les moteurs
    digitalWrite(in1, LOW);
    digitalWrite(in2, LOW);
    digitalWrite(in3, LOW);
    digitalWrite(in4, LOW);
    analogWrite(enA, 0); // Utiliser analogWrite pour arrêter
    analogWrite(enB, 0); // Utiliser analogWrite pour arrêter

    angle2 = 0; // Déplacer le deuxième servo à 0 degrés
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à ce nouvel angle
  }

  // Vérifie si la tâche est en cours et si les servos sont arrivés à leurs positions finales
  if (taskInProgress1 && myServo1.read() == 0 && myServo2.read() == 0) {
    delay(1000);  // Attendre une seconde
    angle1 = 35;   // Remettre le premier servo à 35 degrés
    angle2 = 65;   // Remettre le deuxième servo à 65 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à l'angle initial
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à l'angle initial
    taskInProgress1 = false; // Marquer la tâche du premier servo comme terminée
  }

  // Vérifie si le deuxième bouton est appuyé et si aucune tâche du deuxième servo n'est en cours
  if (digitalRead(BUTTON_PIN_2) == LOW && !taskInProgress2) {
    // Tourner les moteurs vers l'avant
    digitalWrite(in1, HIGH);
    digitalWrite(in2, LOW);
    digitalWrite(in3, HIGH);
    digitalWrite(in4, LOW);
    analogWrite(enA, 100); // Utiliser analogWrite pour la vitesse
    analogWrite(enB, 100); // Utiliser analogWrite pour la vitesse
    delay(3000);

    // Arrêter les moteurs
    digitalWrite(in1, LOW);
    digitalWrite(in2, LOW);
    digitalWrite(in3, LOW);
    digitalWrite(in4, LOW);
    analogWrite(enA, 0); // Utiliser analogWrite pour arrêter
    analogWrite(enB, 0); // Utiliser analogWrite pour arrêter

    angle1 = 0; // Déplacer le premier servo à 0 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à ce nouvel angle

    // Tourner les moteurs vers l'arrière
    digitalWrite(in1, LOW);
    digitalWrite(in2, HIGH);
    digitalWrite(in3, LOW);
    digitalWrite(in4, HIGH);
    analogWrite(enA, 100); // Utiliser analogWrite pour la vitesse
    analogWrite(enB, 100); // Utiliser analogWrite pour la vitesse
    delay(3000);

    // Arrêter les moteurs
    digitalWrite(in1, LOW);
    digitalWrite(in2, LOW);
    digitalWrite(in3, LOW);
    digitalWrite(in4, LOW);
    analogWrite(enA, 0); // Utiliser analogWrite pour arrêter
    analogWrite(enB, 0); // Utiliser analogWrite pour arrêter

    angle1 = 70; // Déplacer le premier servo à 70 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à ce nouvel angle

    // Tourner les moteurs vers l'avant
    digitalWrite(in1, HIGH);
    digitalWrite(in2, LOW);
    digitalWrite(in3, HIGH);
    digitalWrite(in4, LOW);
    analogWrite(enA, 100); // Utiliser analogWrite pour la vitesse
    analogWrite(enB, 100); // Utiliser analogWrite pour la vitesse
    delay(3000);

    // Arrêter les moteurs
    digitalWrite(in1, LOW);
    digitalWrite(in2, LOW);
    digitalWrite(in3, LOW);
    digitalWrite(in4, LOW);
    analogWrite(enA, 0); // Utiliser analogWrite pour arrêter
    analogWrite(enB, 0); // Utiliser analogWrite pour arrêter

    angle1 = 35; // Déplacer le premier servo à 35 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à ce nouvel angle

    angle2 = 0; // Déplacer le deuxième servo à 0 degrés
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à ce nouvel angle
  }

  // Vérifie si la tâche du deuxième servo est en cours et si le deuxième servo est arrivé à sa position finale
  if (taskInProgress2 && myServo1.read() == 0 && myServo2.read() == 0) {
    delay(1000);  // Attendre une seconde
    angle1 = 35;   // Remettre le premier servo à 35 degrés
    angle2 = 65;   // Remettre le deuxième servo à 65 degrés
    myServo1.write(angle1);  // Faire pivoter le premier servo à l'angle initial
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à l'angle initial
    taskInProgress2 = false; // Marquer la tâche du deuxième servo comme terminée
  }

  // Vérifie si le troisième bouton est appuyé et si aucune tâche du troisième bouton n'est en cours
  if (digitalRead(BUTTON_PIN_3) == LOW && !taskInProgress3) {
    taskInProgress3 = true; // Marquer la tâche du troisième bouton comme en cours
    angle2 = 90; // Déplacer le deuxième servo à 90 degrés
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à ce nouvel angle
    delay(1000);  // Attendre une seconde
    angle2 = 65;   // Remettre le deuxième servo à 65 degrés
    myServo2.write(angle2);  // Faire pivoter le deuxième servo à l'angle initial
    taskInProgress3 = false; // Marquer la tâche du troisième bouton comme terminée
  }
}
